@@ -30,7 +30,7 @@ $.fn.postprocess = function (className, options) {
                 var data = $(this).attr('resty_value');
                 var type = $(this).attr('resty_type');
                 //debug(type);
-                if (/\n.*?\n/.test(data)) {
+                if (data.length > 128 || /\n.*?\n/.test(data)) {
                     type = 'textarea';
                 }
                 if (!type) type = 'text';
@@ -189,7 +189,7 @@ function getPager (name, page, prefix) {
         renderPager(res, page, prefix);
     };
     openresty.postByGet(
-        '/=/action/.Select/lang/minisql',
+        '/=/action/RunView/~/~',
         "select count(*) as count from " + name
     );
 }
